@@ -1,6 +1,6 @@
 package Server::Control;
 BEGIN {
-  $Server::Control::VERSION = '0.15';
+  $Server::Control::VERSION = '0.16';
 }
 use Capture::Tiny;
 use File::Basename;
@@ -43,19 +43,15 @@ if ( my $moosex_traits_error = $@ ) {
 # Note: In some cases we use lazy_build rather than specifying required or a
 # default, to make life easier for subclasses.
 #
-has 'bind_addr'   => ( is => 'ro', isa => 'Str', lazy_build => 1 );
-has 'description' =>
-( is => 'ro', isa => 'Str', lazy_build => 1, init_arg => undef );
-
+has 'bind_addr'            => ( is => 'ro', isa => 'Str', lazy_build => 1 );
+has 'description'          => ( is => 'ro', isa => 'Str', lazy_build => 1, init_arg => undef );
 has 'error_log'            => ( is => 'ro', isa => 'Str', lazy_build => 1 );
 has 'log_dir'              => ( is => 'ro', isa => 'Str', lazy_build => 1 );
 has 'name'                 => ( is => 'ro', isa => 'Str', lazy_build => 1 );
 has 'pid_file'             => ( is => 'ro', isa => 'Str', lazy_build => 1 );
 has 'poll_for_status_secs' => ( is => 'ro', isa => 'Num', default => 0.2 );
 has 'port'                 => ( is => 'ro', isa => 'Int', lazy_build => 1 );
-has 'restart_method' =>
-( is => 'ro', isa => enum( [qw(hup stopstart)] ), default => 'stopstart' );
-
+has 'restart_method'       => ( is => 'ro', isa => enum( [qw(hup stopstart)] ), default => 'stopstart' );
 has 'server_root'          => ( is => 'ro', isa => 'Str' );
 has 'use_sudo'             => ( is => 'ro', isa => 'Bool', lazy_build => 1 );
 has 'wait_for_hup_secs'    => ( is => 'ro', isa => 'Num', default => 0.5 );
@@ -734,7 +730,7 @@ Server::Control -- Flexible apachectl style control for servers
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
